<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>InvertSelection</name>
    <message>
        <location filename="../InvertSelectionInit.js" line="+2"/>
        <source>&amp;Invert Selection</source>
        <translation>&amp;Inverti selezione</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Invert the current selection</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Invertire la selezione corrente</translation>
    </message>
</context>
</TS>
